@@ -1,7 +1,7 @@
 from urequests import post
 from network import WLAN
 
-__version__ = '0.0.2'
+__version__ = '0.0.5'
 __author__ = 'Teeraphat Kullanankanjana'
 
 class LineNotify():
@@ -89,5 +89,5 @@ class LineNotify():
         500: Failure due to server error
         Other: Processed over time or stopped
         """
-        self.__msg = 'message={}&imageThumbnail={}&imageFullsize={}'.format(msg,url,url).encode('utf-8')
+        payload = 'message={}&imageThumbnail={}&imageFullsize={}'.format(msg,url,url).encode('utf-8')
         httpCode = self.__sendRequest(payload)
